@@ -1327,7 +1327,7 @@ Curses::UI::TextEditor - Create and manipulate texteditor widgets
     my $win = $cui->add('window_id', 'Window');
 
     my $editor = $win->add(
-        'myeditor', 'Editor',
+        'myeditor', 'TextEditor',
         -vscrollbar => 1,
         -wrapping   => 1,
     );
